@@ -1,19 +1,18 @@
 import asyncio
 import shlex
 from collections import deque
-from functools import lru_cache, singledispatch
+from functools import singledispatch
 from pathlib import Path
 from typing import Any, List, Optional, Tuple
 
 from ._logger import logger
 from .constants import (
-    AIOPYTESSERACT_DEFAULT_BUILD_CMD_CACHE,
     AIOPYTESSERACT_DEFAULT_ENCODING,
     AIOPYTESSERACT_DEFAULT_TIMEOUT,
     OUTPUT_FILE_EXTENSIONS,
     TESSERACT_CMD,
 )
-from .exceptions import TesseractRuntimeError
+from .exceptions import TesseractRuntimeError, TesseractTimeoutError
 from .returncode import ReturnCode
 from .validators import file_exists, language_is_valid, oem_is_valid, psm_is_valid
 
@@ -64,7 +63,7 @@ async def _(
     user_patterns: Optional[str] = None,
     tessdata_dir: Optional[str] = None,
 ) -> bytes:
-    file_exists(image)
+    await file_exists(image)
     response: bytes = await execute(
         Path(image).read_bytes(),
         output_format,
@@ -94,7 +93,7 @@ async def _(
     tessdata_dir: Optional[str] = None,
     encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING,
 ) -> bytes:
-    cmd_args = _build_cmd_args(
+    cmd_args = await _build_cmd_args(
         output_extension=output_format,
         dpi=dpi,
         psm=psm,
@@ -120,7 +119,7 @@ async def _(
         )
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     if proc.returncode != ReturnCode.SUCCESS:
         raise TesseractRuntimeError(stderr.decode(encoding))
     return stdout
@@ -140,7 +139,7 @@ async def execute_multi_output_cmd(
     tessdata_dir: Optional[str] = None,
     encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING,
 ) -> Tuple[str, ...]:
-    cmd_args = _build_cmd_args(
+    cmd_args = await _build_cmd_args(
         output_extension=output_format,
         dpi=dpi,
         psm=psm,
@@ -165,7 +164,7 @@ async def execute_multi_output_cmd(
         _, stderr = await asyncio.wait_for(proc.communicate(image), timeout=timeout)
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     if proc.returncode != ReturnCode.SUCCESS:
         raise TesseractRuntimeError(stderr.decode(encoding))
     return tuple(
@@ -173,8 +172,7 @@ async def execute_multi_output_cmd(
     )
 
 
-@lru_cache(maxsize=AIOPYTESSERACT_DEFAULT_BUILD_CMD_CACHE)
-def _build_cmd_args(
+async def _build_cmd_args(
     output_extension: str,
     dpi: int,
     psm: int,
@@ -185,26 +183,27 @@ def _build_cmd_args(
     lang: Optional[str] = None,
     output: str = "stdout",
 ) -> List[str]:
-    psm_is_valid(psm)
-    oem_is_valid(oem)
+    await asyncio.gather(psm_is_valid(psm), oem_is_valid(oem))
+    # OCR options must occur before any configfile.
+    # for details type: tesseract --help-extra
 
     cmd_args = deque(
         ["stdin", f"{output}", "--dpi", f"{dpi}", "--psm", f"{psm}", "--oem", f"{oem}"]
     )
-    if user_words:
-        cmd_args.append("--user-words")
-        cmd_args.append(user_words)
-
     if user_patterns:
-        cmd_args.append("--user-patterns")
-        cmd_args.append(user_patterns)
+        cmd_args.appendleft(user_patterns)
+        cmd_args.appendleft("--user-patterns")
+
+    if user_words:
+        cmd_args.appendleft(user_words)
+        cmd_args.appendleft("--user-words")
 
     if tessdata_dir:
-        cmd_args.append("--tessdata-dir")
-        cmd_args.append(tessdata_dir)
+        cmd_args.appendleft(tessdata_dir)
+        cmd_args.appendleft("--tessdata-dir")
 
     if lang:
-        language_is_valid(lang)
+        await language_is_valid(lang)
         cmd_args.append("-l")
         cmd_args.append(lang)
 
