@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import Any, AsyncGenerator, List, Optional, Tuple
 
 import cattr
-from aiofiles import tempfile  # type: ignore
+from aiofiles import tempfile
 
 from aiopytesseract.validators import file_exists
 
@@ -20,7 +20,7 @@ from .constants import (
     AIOPYTESSERACT_DEFAULT_TIMEOUT,
     TESSERACT_LANGUAGES,
 )
-from .exceptions import TesseractRuntimeError
+from .exceptions import TesseractRuntimeError, TesseractTimeoutError
 from .file_format import FileFormat
 from .models import OSD, Box, Data, Parameter
 from .returncode import ReturnCode
@@ -28,35 +28,49 @@ from .returncode import ReturnCode
 
 async def languages(
     config: str = "", encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING
-) -> List:
-    """Tesseract available languages."""
+) -> List[str]:
+    """Tesseract available languages.
+
+    :param config: config. (valid values: str)
+    :param encoding: decode bytes to string. (default: utf-8)
+    """
     proc = await execute_cmd(f"--list-langs {config}")
     data = await proc.stdout.read()
-    languages = []
+    langs = []
     for line in data.decode(encoding).split():
         lang = line.strip()
         if lang in TESSERACT_LANGUAGES:
-            languages.append(lang)
-    return languages
+            langs.append(lang)
+    return langs
 
 
 async def get_languages(
     config: str = "", encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING
-) -> List:
-    """Tesseract available languages."""
+) -> List[str]:
+    """Tesseract available languages.
+
+    :param config: config. (valid values: str)
+    :param encoding: decode bytes to string. (default: utf-8)
+    """
     langs = await languages(config, encoding=encoding)
     return langs
 
 
 async def tesseract_version(encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING) -> str:
-    """Tesseract version."""
+    """Tesseract version.
+
+    :param encoding: decode bytes to string. (default: utf-8)
+    """
     proc = await execute_cmd("--version")
     data: bytes = await proc.stdout.readuntil()
     return data.decode(encoding).split()[1]
 
 
 async def get_tesseract_version(encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING) -> str:
-    """Tesseract version."""
+    """Tesseract version.
+
+    :param encoding: decode bytes to string. (default: utf-8)
+    """
     version = await tesseract_version(encoding)
     return version
 
@@ -72,9 +86,11 @@ async def confidence(
     """Get script confidence.
 
     :param image: image input to tesseract. (valid values: str)
-    :param dpi: image dots per inch (DPI)
-    :param oem: ocr engine modes (default: 3)
-    :param timeout: command timeout (default: 30)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
+    :param oem: ocr engine modes. (default: 3)
+    :param timeout: command timeout. (default: 30)
+    :param encoding: decode bytes to string. (default: utf-8)
     """
     try:
         proc = await execute_cmd(
@@ -91,7 +107,7 @@ async def confidence(
         )
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     except AttributeError:
         confidence_value = 0.0
     return confidence_value
@@ -108,10 +124,11 @@ async def deskew(
     """Get Deskew angle.
 
     :param image: image input to tesseract. (valid values: str)
-    :param dpi: image dots per inch (DPI)
-    :param oem: ocr engine modes (default: 3)
-    :param lang: tesseract language. (Format: eng, eng+por, eng+por+fra)
-    :param timeout: command timeout (default: 30)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
+    :param oem: ocr engine modes. (default: 3)
+    :param timeout: command timeout. (default: 30)
+    :param encoding: decode bytes to string. (default: utf-8)
     """
     try:
         proc = await execute_cmd(
@@ -126,7 +143,7 @@ async def deskew(
         )
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     except AttributeError:
         deskew_value = 0.0
     return deskew_value
@@ -137,14 +154,16 @@ async def tesseract_parameters(
 ) -> List[Parameter]:
     """List of all Tesseract parameters with default value and short description.
 
-    reference: https://tesseract-ocr.github.io/tessdoc/tess3/ControlParams.html
+    - reference: https://tesseract-ocr.github.io/tessdoc/tess3/ControlParams.html
+
+    :param encoding: decode bytes to string. (default: utf-8)
     """
     proc = await execute_cmd("--print-parameters")
     raw_data: bytes = await proc.stdout.read()
     data = raw_data.decode(encoding)
     params = []
     for line in data.split("\n"):
-        param = re.search(r"(\w+)\s+(-?\d+.?\d{0,})\s+(.*)[^\n]$", line)
+        param = re.search(r"(\w+)\s+(-?\d+.?\d*)\s+(.*)[^\n]$", line)
         if param:
             params.append(
                 cattr.structure_attrs_fromtuple(
@@ -169,13 +188,14 @@ async def image_to_string(
     """Extract string from an image.
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param user_words: location of user words file
-    :param user_patterns: location of user patterns file
-    :param dpi: image dots per inch (DPI)
-    :param lang: tesseract language. (Format: eng, eng+por, eng+por+fra)
-    :param psm: page segmentation modes (default: 3)
-    :param oem: ocr engine modes (default: 3)
-    :param timeout: command timeout (default: 30)
+    :param user_words: location of user words file. (default: None)
+    :param user_patterns: location of user patterns file. (default: None)
+    :param tessdata_dir: location of tessdata path. (default: None)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
+    :param psm: page segmentation modes. (default: 3)
+    :param oem: ocr engine modes. (default: 3)
+    :param timeout: command timeout. (default: 30)
     """
     raise NotImplementedError(f"Type {type(image)} not supported.")
 
@@ -251,10 +271,11 @@ async def image_to_hocr(
     """HOCR
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param user_words: location of user words file
-    :param user_patterns: location of user patterns file
-    :param dpi: image dots per inch (DPI)
-    :param lang: tesseract language. (Format: eng, eng+por, eng+por+fra)
+    :param user_words: location of user words file. (default: None)
+    :param user_patterns: location of user patterns file. (default: None)
+    :param tessdata_dir: location of tessdata path. (default: None)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
     :param psm: page segmentation modes (default: 3)
     :param oem: ocr engine modes (default: 3)
     :param timeout: command timeout (default: 30)
@@ -333,13 +354,14 @@ async def image_to_pdf(
     """Generate a searchable PDF from an image.
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param user_words: location of user words file
-    :param user_patterns: location of user patterns file
-    :param dpi: image dots per inch (DPI)
-    :param lang: tesseract language. (Format: eng, eng+por, eng+por+fra)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
     :param psm: page segmentation modes (default: 3)
     :param oem: ocr engine modes (default: 3)
     :param timeout: command timeout (default: 30)
+    :param user_words: location of user words file. (default: None)
+    :param user_patterns: location of user patterns file. (default: None)
+    :param tessdata_dir: location of tessdata path. (default: None)
     """
     raise NotImplementedError
 
@@ -412,7 +434,7 @@ async def image_to_boxes(
 
 @image_to_boxes.register(str)
 async def _(image: str, timeout: float = AIOPYTESSERACT_DEFAULT_TIMEOUT) -> List[Box]:
-    file_exists(image)
+    await file_exists(image)
     boxes = await image_to_boxes(Path(image).read_bytes(), timeout)
     return boxes
 
@@ -430,7 +452,7 @@ async def _(
         )
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     if proc.returncode != ReturnCode.SUCCESS:
         raise TesseractRuntimeError(stderr.decode(encoding))
     data = stdout.decode(encoding)
@@ -450,7 +472,8 @@ async def image_to_data(
     """Information about boxes, confidences, line and page numbers.
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param dpi: image dots per inch (DPI)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param timeout: command timeout (default: 30)
     """
     raise NotImplementedError
 
@@ -461,7 +484,7 @@ async def _(
     dpi: int = AIOPYTESSERACT_DEFAULT_DPI,
     timeout: float = AIOPYTESSERACT_DEFAULT_TIMEOUT,
 ) -> List[Data]:
-    file_exists(image)
+    await file_exists(image)
     data_values = await image_to_data(Path(image).read_bytes(), dpi, timeout)
     return data_values
 
@@ -480,7 +503,7 @@ async def _(
         )
     except asyncio.TimeoutError:
         proc.kill()
-        raise RuntimeError("Tesseract process timeout")
+        raise TesseractTimeoutError()
     if proc.returncode != ReturnCode.SUCCESS:
         raise TesseractRuntimeError(stderr.decode(encoding))
     data: str = stdout.decode(encoding)
@@ -503,9 +526,10 @@ async def image_to_osd(
     """Information about orientation and script detection.
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param dpi: image dots per inch (DPI)
-    :param oem: ocr engine modes (default: 3)
-    :param timeout: command timeout (default: 30)
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param oem: ocr engine modes. (default: 3)
+    :param timeout: command timeout. (default: 30)
+    :param encoding: decode bytes to string. (default: utf-8)
     """
     raise NotImplementedError
 
@@ -518,7 +542,7 @@ async def _(
     timeout: float = AIOPYTESSERACT_DEFAULT_TIMEOUT,
     encoding: str = AIOPYTESSERACT_DEFAULT_ENCODING,
 ) -> OSD:
-    file_exists(image)
+    await file_exists(image)
     osd = await image_to_osd(Path(image).read_bytes(), dpi, oem, timeout, encoding)
     return osd
 
@@ -534,7 +558,7 @@ async def _(
     data = await execute(image, FileFormat.OSD, dpi, None, 0, oem, timeout)
     osd = cattr.structure_attrs_fromtuple(
         re.findall(  # type: ignore
-            r"\w+\s?\:\s{0,}(\d+.?\d{0,}|\w+)",
+            r"\w+\s?:\s*(\d+.?\d*|\w+)",
             data.decode(encoding),
         ),
         OSD,
@@ -564,13 +588,16 @@ async def run(
     - https://github.com/tesseract-ocr/tesseract/blob/main/doc/tesseract.1.asc#inout-arguments
 
     :param image: image input to tesseract. (valid values: str, bytes)
-    :param user_words: location of user words file
-    :param user_patterns: location of user patterns file
-    :param dpi: image dots per inch (DPI)
-    :param lang: tesseract language. (Format: eng, eng+por, eng+por+fra)
-    :param psm: page segmentation modes (default: 3)
-    :param oem: ocr engine modes (default: 3)
-    :param timeout: command timeout (default: 30)
+    :param output_filename: base filename.
+    :param output_format: output file extensions.
+    :param dpi: image dots per inch (DPI). (default: 300)
+    :param lang: tesseract language. (default: eng, format: eng, eng+por, eng+por+fra)
+    :param psm: page segmentation modes. (default: 3)
+    :param oem: ocr engine modes. (default: 3)
+    :param timeout: command timeout. (default: 30)
+    :param user_words: location of user words file. (default: None)
+    :param user_patterns: location of user patterns file. (default: None)
+    :param tessdata_dir: location of tessdata path. (default: None)
     """
     if not isinstance(image, bytes):
         raise NotImplementedError
