@@ -3,6 +3,7 @@ from pathlib import Path
 import pytest
 
 import aiopytesseract
+from aiopytesseract.exceptions import TesseractRuntimeError
 from aiopytesseract.models import Data
 
 
@@ -26,7 +27,7 @@ async def test_image_to_data_with_bytes_image(image):
 
 @pytest.mark.asyncio
 async def test_image_to_data_with_invalid():
-    with pytest.raises(RuntimeError):
+    with pytest.raises(TesseractRuntimeError):
         await aiopytesseract.image_to_data("tests/samples/file-sample_150kB.pdf")
 
 
